==> eagle-i-repository-webapp-1.0-MS6.07-sources.jar: jsp/index_jsp.java <==
package jsp;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import org.eaglei.repository.DataRepository;
import org.eaglei.repository.status.ErrorSendingException;

public final class index_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\" xml:lang=\"en\">\n\n\n<head>\n");

    try {

      out.write('\n');

    String redir = DataRepository.getInstance().getConfigurationProperty("eaglei.repository.index.url");
    if (redir != null) {

      out.write("\n        <meta http-equiv=\"Refresh\" content=\"0;URL=");
      out.print( redir );
      out.write("\"/>\n");

    }

      out.write("\n</head>\n<body>\n<title>Default eagle-i Root</title>\n");

    if (redir == null) {

      out.write("\n<h1>Configuration Error</h1>\nYour eagle-i application administrator needs to set the\n<b><code>eaglei.repository.index.url</code></b> property in the data repository's\nconfiguration properties.  Its value is the URL of a site home page to which\nthis top-level index page will redirect.\n");

    } else {

      out.write("\n    <h2><i>Please wait while your browser is redirected..</i></h2>\n    <br/>\n    <a href=\"");
      out.print( redir );
      out.write("\">Click here if your session is not redirected momentarily.</a>\n");

    }

      out.write("\n</body>\n");

    // see "try" at start of head tag.
    // This is the idiom that much of the repo code uses to pass
    // HTTP status results back as a RuntimeException subclass..
    } catch (ErrorSendingException e) {
        response.sendError(e.getStatus(), e.getMessage());
    }

      out.write("\n</html>\n                  \n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}

==> eagle-i-repository-webapp-1.1-MS4.00-sources.jar: jsp/index_jsp.java <==
package jsp;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import org.eaglei.repository.DataRepository;
import org.eaglei.repository.status.ErrorSendingException;
import org.eaglei.repository.util.Utils;

public final class index_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html;charset=UTF-8");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\" xml:lang=\"en\">\n\n\n\n<head>\n    <meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\"/>\n");

    try {

      out.write('\n');

    String redir = DataRepository.getInstance().getConfigurationProperty("eaglei.repository.index.url");
    if (redir != null) {

      out.write("\n        <meta http-equiv=\"Refresh\" content=\"0;URL=");
      out.print( Utils.escapeHTMLAttribute(redir) );
      out.write("\"/>\n");

    }

      out.write("\n</head>\n<body>\n<title>Default eagle-i Root</title>\n");

    if (redir == null) {

      out.write("\n<h1>Configuration Error</h1>\nYour eagle-i application administrator needs to set the\n<b><code>eaglei.repository.index.url</code></b> property in the data repository's\nconfiguration properties.  Its value is the URL of a site home page to which\nthis top-level index page will redirect.\n");

    } else {

      out.write("\n    <h2><i>Please wait while your browser is redirected..</i></h2>\n    <br/>\n    <a href=\"");
      out.print( redir );
      out.write("\">Click here if your session is not redirected momentarily.</a>\n");

    }

      out.write("\n</body>\n");

    // see "try" at start of head tag.
    // This is the idiom that much of the repo code uses to pass
    // HTTP status results back as a RuntimeException subclass..
    } catch (ErrorSendingException e) {
        response.sendError(e.getStatus(), e.getMessage());
    }

      out.write("\n</html>\n                  \n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}
